<?php

namespace App\Http\Controllers;

use App\Models\RatingToken;
use App\Models\Rating;
use App\Mail\RatingLinkMail;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Mail;
use Carbon\Carbon;
use App\Models\Client;
// use App\Models\SupportCase;

class RatingController extends Controller
{

    public function index()
    {
        $clients = Client::all(); // se obtiene todos los clientes

        return view('ratings.index', compact('clients'));
    }
    
    public function sendRatingLink(Request $request)
    {
        $request->validate([
            'email' => 'required|email'
        ]);

        RatingToken::where('email', $request->email)->delete();

        $token = bin2hex(random_bytes(16));
        $expiresAt = Carbon::now()->addDay(1);

        RatingToken::create([
            'email' => $request->email,
            'token' => $token,
            'expires_at' => $expiresAt
        ]);

        $link = url('/rating/' . $token);
        Mail::to($request->email)->send(new RatingLinkMail($link));

        return back()->with('success', '¡El enlace de calificación ha sido enviado a tu correo!');
    }

    public function showRatingForm($token)
    {
        $ratingToken = RatingToken::where('token', $token)
                                  ->where('expires_at', '>', Carbon::now())
                                  ->first();

        if (!$ratingToken) {
            return redirect('/')->with('error', 'Este enlace ha expirado o es inválido.');
        }

        $client = Client::where('email', $ratingToken->email)->first();

        return view('rating-form', [
            'token' => $token,
            'client' => $client
        ]);
    }

    public function submitRating(Request $request)
    {
        $request->validate([
            // 'name' => 'required',
            // 'email' => 'required|email',
            // 'company' => 'required',
            'rating' => 'required|integer|min:1|max:5',
            'token' => 'required',
            'comments' => 'nullable|string|max:500',
        ]);

        $ratingToken = RatingToken::where('token', $request->token)->first();

        if (!$ratingToken) {
            return redirect('/')->with('error', 'El enlace de calificación no es válido o ha expirado.');
        }

        $client = Client::where('email', $request->email)->first();

        if (!$client) {
            $client = Client::create([
                'name' => $request->name,
                'email' => $request->email,
                'company' => $request->company
            ]);
        }

        Rating::create([
            'client_id' => $client->id, 
            'rating' => $request->rating,
            'comments' => $request->comments,
        ]);

        $ratingToken->delete();
        return redirect()->route('thank-you');
    }

    public function showRatings()
    {
        $clients = Client::with('ratings')->get(); // se obtiene los clientes con sus calificaciones
        // $clients = Client::with('ratings', 'ratings.support.consultant')->get(); // se obtiene los clientes con sus calificaciones
        return view('ratings.ratings', compact('clients'));
    }

}
