<?php

namespace App\Http\Controllers;

use App\Models\Task;
use Illuminate\Http\Request;
use App\Models\User;
use Carbon\Carbon;
use App\Notifications\TaskNotification;
use App\Events\TaskEvent;


class TaskController extends Controller
{

    public function __construct()
    {
        $this->middleware('permission:ver-tarea|crear-tarea|editar-tarea|borrar-tarea', ['only' => ['index', 'show']]);
        $this->middleware('permission:crear-tarea', ['only' => ['create', 'store']]);
        $this->middleware('permission:editar-tarea', ['only' => ['edit', 'update']]);
        $this->middleware('permission:borrar-tarea', ['only' => ['destroy']]);
        $this->middleware('permission:ver-notificaciones', ['only' => ['mostrarNotificaciones', 'marcarNotification']]);
    }


    public function index()
    {
        $currentWeekNumber = Carbon::now()->weekOfYear;
        $users = User::all();
        $tasks = Task::where('week_number', $currentWeekNumber)->paginate(20);
        return view('tasks.index', compact('users', 'currentWeekNumber', 'tasks'));
    }


    public function create()
    {
        $users = User::all();
        return view('tasks.create', compact('users'));
    }


    public function store(Request $request, Task $task)
    {
        $weekNumber = Carbon::now()->weekOfYear;

        $weekStartDate = Carbon::now()->startOfWeek()->toDateString();

        $validated = $request->validate([
            'assigned_to' => 'required|integer|exists:users,id',
            'activity' => [
                'required',
                'string',
                'max:50',
                'regex:/^[a-zA-Z0-9áéíóúÁÉÍÓÚüÜñÑ\s\.\-\"\'\,]+$/',
            ],
            'activity_date' => 'required|date',
        ]);

        // $task = new Task();

        $task->assigned_to = $request->assigned_to;
        $task->activity = $request->activity;
        $task->activity_date = $request->activity_date;

        $task->week_number = $weekNumber;
        $task->week_start_date = $weekStartDate;

        $task->user_id = auth()->id(); // usuario autenticado

        $task->save();

        event(new TaskEvent($task));

        // auth()->user()->notify(new TaskNotification($task));

        return redirect()->route('tasks.index')->with('success', 'Tarea creado exitosamente');
    }

    public function mostrarNotificaciones()
    {
        $taskNotifications = auth()->user()->notifications;
        return view('tasks.notification', compact('taskNotifications'));
    }

    public function marcarNotification(Request $request)
    {
        auth()->user()->unreadNotifications
            ->when($request->input('id'), function ($query) use ($request) {
                return $query->where('id', $request->input('id'));
            })->markAsRead();
        return response()->noContent();
    }


    public function show(Task $task)
    {
        //
    }


    public function edit(Task $task)
    {
        $users = User::all();
        return view('tasks.edit', compact('task', 'users'));
    }



    public function update(Request $request, Task $task)
    {
        $validated = $request->validate([
            'assigned_to' => 'required|integer|exists:users,id',
            'activity' => [
                'required',
                'string',
                'max:50',
                'regex:/^[a-zA-Z0-9áéíóúÁÉÍÓÚüÜñÑ\s\.\-\"\'\,]+$/',
            ],
            'activity_date' => 'required|date',
        ]);

        $task->assigned_to = $request->assigned_to;
        $task->activity = $request->activity;
        $task->activity_date = $request->activity_date;

        $task->save();
        return redirect()->route('tasks.index')->with('success', 'Tarea actualizado exitosamente');
    }



    public function destroy(Task $task)
    {
        $task->delete();
        return redirect()->route('tasks.index')->with('deleted', 'Tarea eliminado exitosamente.');
    }
}
