document.addEventListener('DOMContentLoaded', function () {
    const form = document.getElementById('caseForm');
    const requestDateInput = document.getElementById('request_date');
    const typeInput = document.getElementById('type');
    const issueDescriptionInput = document.getElementById('issue_description');
    const solutionInput = document.getElementById('solution');
    const resolutionDateInput = document.getElementById('resolution_date');
    const startTimeInput = document.getElementById('start_time');
    const endTimeInput = document.getElementById('end_time');
    const opportunityInput = document.getElementById('opportunity');

    const requestDateError = document.getElementById('requestDateError');
    const typeError = document.getElementById('typeError');
    const issueDescriptionError = document.getElementById('issueDescriptionError');
    const solutionError = document.getElementById('solutionError');
    const resolutionDateError = document.getElementById('resolutionDateError');
    const startTimeError = document.getElementById('startTimeError');
    const endTimeError = document.getElementById('endTimeError');
    const opportunityError = document.getElementById('opportunityError');

    // Validaciones al recibir un cambio en los campos
    requestDateInput.addEventListener('input', validateRequestDate);
    typeInput.addEventListener('input', validateType);
    issueDescriptionInput.addEventListener('input', validateIssueDescription);
    solutionInput.addEventListener('input', validateSolution);
    resolutionDateInput.addEventListener('input', validateResolutionDate);
    startTimeInput.addEventListener('input', validateStartTime);
    endTimeInput.addEventListener('input', validateEndTime);
    opportunityInput.addEventListener('input', validateOpportunity);


    function validateRequestDate() {
        const requestDateValue = requestDateInput.value;
        const today = new Date();
        const inputDate = new Date(requestDateValue);

        // Verifica que la fecha de solicitud esté dentro de una semana (7 días) de la fecha actual
        const oneWeekBefore = new Date();
        oneWeekBefore.setDate(today.getDate() - 7);

        // Si la fecha es vacía
        if (!requestDateValue) {
            requestDateError.textContent = 'La fecha de solicitud es obligatoria.';
            requestDateError.style.display = 'block';
        }
        // Si la fecha no es válida
        else if (isNaN(inputDate)) {
            requestDateError.textContent = 'La fecha de solicitud no es válida.';
            requestDateError.style.display = 'block';
        }
        // Si la fecha es más antigua que 7 días antes de la fecha actual
        else if (inputDate < oneWeekBefore) {
            requestDateError.textContent = 'La fecha de solicitud no puede ser más antigua que 7 días antes de la fecha actual.';
            requestDateError.style.display = 'block';
        }
        // Si la fecha es válida
        else {
            requestDateError.style.display = 'none';
        }
    }


    function validateType() {
        const regex = /^[a-zA-Z0-9áéíóúÁÉÍÓÚüÜñÑ\s\.\-\"\'\,]+$/;
        if (!typeInput.value) {
            typeError.textContent = 'El tipo es obligatorio.';
            typeError.style.display = 'block';
        } else if (!regex.test(typeInput.value)) {
            typeError.textContent = 'El tipo solo puede contener letras, números, espacios, puntos, guiones, acentos, comillas y comas.';
            typeError.style.display = 'block';
        } else if (typeInput.value.length > 50) {
            typeError.textContent = 'El tipo no puede exceder los 50 caracteres.';
            typeError.style.display = 'block';
        } else {
            typeError.style.display = 'none';
        }
    }


    function validateIssueDescription() {
        const regex = /^[a-zA-Z0-9áéíóúÁÉÍÓÚüÜñÑ\s\.\-\"\'\,]+$/;
        if (!issueDescriptionInput.value) {
            issueDescriptionError.textContent = 'El caso reportado es obligatoria.';
            issueDescriptionError.style.display = 'block';
        } else if (!regex.test(issueDescriptionInput.value)) {
            issueDescriptionError.textContent = 'El caso reportado solo puede contener letras, números, espacios, puntos, guiones, acentos, comillas y comas.';
            issueDescriptionError.style.display = 'block';
        } else if (issueDescriptionInput.value.length > 255) {
            issueDescriptionError.textContent = 'El caso reportado no puede exceder los 255 caracteres.';
            issueDescriptionError.style.display = 'block';
        } else {
            issueDescriptionError.style.display = 'none';
        }
    }


    function validateSolution() {
        const regex = /^[a-zA-Z0-9áéíóúÁÉÍÓÚüÜñÑ\s\.\-\"\'\,]+$/;
        if (!solutionInput.value) {
            solutionError.textContent = 'La solución es obligatoria.';
            solutionError.style.display = 'block';
        } else if (!regex.test(solutionInput.value)) {
            solutionError.textContent = 'La solución solo puede contener letras, números, espacios, puntos, guiones, acentos, comillas y comas.';
            solutionError.style.display = 'block';
        } else if (solutionInput.value.length > 255) {
            solutionError.textContent = 'La solución no puede exceder los 255 caracteres.';
            solutionError.style.display = 'block';
        } else {
            solutionError.style.display = 'none';
        }
    }

    function validateResolutionDate() {
        const requestDateValue = requestDateInput.value;
        const resolutionDateValue = resolutionDateInput.value;

        const requestDate = new Date(requestDateValue);
        const resolutionDate = new Date(resolutionDateValue);


        if (!resolutionDateValue) {
            resolutionDateError.textContent = 'La fecha de resolución es obligatoria.';
            resolutionDateError.style.display = 'block';
        } else if (isNaN(resolutionDate)) {
            resolutionDateError.textContent = 'La fecha de resolución no es válida.';
            resolutionDateError.style.display = 'block';
        }

        else if (resolutionDate < requestDate) {  // Solo debe fallar si es ANTES
            resolutionDateError.textContent = 'La fecha de resolución no puede ser anterior a la fecha de solicitud.';
            resolutionDateError.style.display = 'block';
        }
        else {
            resolutionDateError.style.display = 'none';
        }
    }


    function validateStartTime() {
        const startTimeValue = startTimeInput.value;

        if (!startTimeValue) {
            startTimeError.textContent = 'La hora de inicio es obligatoria.';
            startTimeError.style.display = 'block';
        } else {
            startTimeError.style.display = 'none';
        }
    }


    function validateEndTime() {
        const startTimeValue = startTimeInput.value;
        const endTimeValue = endTimeInput.value;

        if (!endTimeValue) {
            endTimeError.textContent = 'La hora de fin es obligatoria.';
            endTimeError.style.display = 'block';
        } else {
            // Convertir las horas a objetos Date para la comparación
            const startTime = new Date('1970-01-01T' + startTimeValue + 'Z'); // Hora de inicio
            const endTime = new Date('1970-01-01T' + endTimeValue + 'Z'); // Hora de fin

            // Verificar que la hora de fin no sea menor que la hora de inicio
            if (endTime <= startTime) {
                endTimeError.textContent = 'La hora de fin no puede ser menor que la hora de inicio.';
                endTimeError.style.display = 'block';
            } else {
                endTimeError.style.display = 'none';
            }
        }
    }


    function validateOpportunity() {
        const regex = /^[a-zA-Z0-9áéíóúÁÉÍÓÚüÜñÑ\s\.\-\"\'\,]+$/;
        if (opportunityInput.value && !regex.test(opportunityInput.value)) {
            opportunityError.textContent = 'La oportunidad solo puede contener letras, números, espacios, puntos, guiones, acentos, comillas y comas.';
            opportunityError.style.display = 'block';
        } else if (opportunityInput.value.length > 255) {
            opportunityError.textContent = 'La oportunidad no puede exceder los 255 caracteres.';
            opportunityError.style.display = 'block';
        } else {
            opportunityError.style.display = 'none';
        }
    }

    form.addEventListener('submit', function (event) {
        validateRequestDate();
        validateType();
        validateIssueDescription();
        validateSolution();
        validateResolutionDate();
        validateStartTime();
        validateEndTime();
        validateOpportunity();

        if (requestDateError.style.display === 'block' ||
            typeError.style.display === 'block' ||
            issueDescriptionError.style.display === 'block' ||
            solutionError.style.display === 'block' ||
            resolutionDateError.style.display === 'block' ||
            startTimeError.style.display === 'block' ||
            endTimeError.style.display === 'block' ||
            opportunityError.style.display === 'block') {
            event.preventDefault();
        }
    });
});
