document.addEventListener('DOMContentLoaded', function () {
    const form = document.getElementById('userForm');
    const nameInput = document.getElementById('name');
    const emailInput = document.getElementById('email');
    const passwordInput = document.getElementById('password');
    const confirmPasswordInput = document.getElementById('confirm-password');
    const photoInput = document.getElementById('photo');
    const nameError = document.getElementById('name-error');
    const emailError = document.getElementById('email-error');
    const passwordError = document.getElementById('password-error');
    const passwordConfirmationError = document.getElementById('password-confirmation-error');

    nameInput.addEventListener('input', validateName);
    emailInput.addEventListener('input', validateEmail);
    passwordInput.addEventListener('input', validatePassword);
    confirmPasswordInput.addEventListener('input', validateConfirmPassword);
    photoInput.addEventListener('change', validatePhoto);

    function validateName() {
        const regex = /^[a-zA-ZáéíóúÁÉÍÓÚüÜñÑ\s]+$/;
        const maxLength = 50;
        const nameValue = nameInput.value;

        if (!nameValue.match(regex)) {
            nameError.textContent = "El nombre solo puede contener letras y espacios.";
            nameError.style.display = 'block';
        } else if (nameValue.length > maxLength) {
            nameError.textContent = `El nombre no puede exceder los ${maxLength} caracteres.`;
            nameError.style.display = 'block';
        } else {
            nameError.style.display = 'none';
        }
    }

    function validateEmail() {
        const regex = /^[\w-\.]+@([\w-]+\.)+[\w-]{2,4}$/;
        const emailValue = emailInput.value;

        if (!regex.test(emailValue)) {
            emailError.textContent = "El correo electrónico no es válido.";
            emailError.style.display = 'block';
        } else {
            emailError.style.display = 'none';
        }
    }

    function validatePassword() {
        const minLength = 8;
        const passwordValue = passwordInput.value;

        if (passwordValue.length < minLength) {
            passwordError.textContent = `La contraseña debe tener al menos ${minLength} caracteres.`;
            passwordError.style.display = 'block';
        } else {
            passwordError.style.display = 'none';
        }
    }

    function validateConfirmPassword() {
        const passwordValue = passwordInput.value;
        const confirmPasswordValue = confirmPasswordInput.value;

        if (confirmPasswordValue !== passwordValue) {
            passwordConfirmationError.textContent = "Las contraseñas no coinciden.";
            passwordConfirmationError.style.display = 'block';
        } else {
            passwordConfirmationError.style.display = 'none';
        }
    }

    function validatePhoto() {
        const file = photoInput.files[0];
        const allowedExtensions = /(\.jpg|\.jpeg|\.png)$/i;
        const maxSize = 2 * 1024 * 1024; // 2 MB

        if (file) {
            if (!allowedExtensions.exec(file.name)) {
                alert("La imagen debe ser JPG, JPEG o PNG.");
                photoInput.value = '';
            } else if (file.size > maxSize) {
                alert("La imagen no puede exceder los 2 MB.");
                photoInput.value = '';
            }
        }
    }

    form.addEventListener('submit', function (event) {
        validateName();
        validateEmail();
        validatePassword();
        validateConfirmPassword();
        validatePhoto();

        if (
            nameError.style.display === 'block' ||
            emailError.style.display === 'block' ||
            passwordError.style.display === 'block' ||
            passwordConfirmationError.style.display === 'block'
        ) {
            event.preventDefault();
        }
    });
});
