document.addEventListener('DOMContentLoaded', function () {
    const form = document.getElementById('userForm');
    const nameInput = document.getElementById('name');
    const emailInput = document.getElementById('email');
    const passwordInput = document.getElementById('password');
    const confirmPasswordInput = document.getElementById('confirm-password');
    const nameError = document.getElementById('name-error');
    const emailError = document.getElementById('email-error');
    const passwordError = document.getElementById('password-error');
    const passwordConfirmationError = document.getElementById('password-confirmation-error');

    nameInput.addEventListener('input', validateName);
    emailInput.addEventListener('input', validateEmail);
    passwordInput.addEventListener('input', validatePassword);
    confirmPasswordInput.addEventListener('input', validatePasswordConfirmation);

    function validateName() {
        const regex = /^[a-zA-ZáéíóúÁÉÍÓÚüÜñÑ\s]+$/;
        if (!regex.test(nameInput.value) || nameInput.value.trim() === '') {
            nameError.textContent = 'El nombre solo puede contener letras y espacios.';
            nameError.style.display = 'block';
        } else {
            nameError.style.display = 'none';
        }
    }

    function validateEmail() {
        const regex = /^[a-zA-Z0-9._-]+@[a-zA-Z0-9.-]+\.[a-zA-Z]{2,6}$/;
        if (!regex.test(emailInput.value)) {
            emailError.textContent = 'Ingrese un correo electrónico válido.';
            emailError.style.display = 'block';
        } else {
            emailError.style.display = 'none';
        }
    }

    function validatePassword() {
        if (passwordInput.value.length > 0 && passwordInput.value.length < 8) {
            passwordError.textContent = 'La contraseña debe tener al menos 8 caracteres.';
            passwordError.style.display = 'block';
        } else {
            passwordError.style.display = 'none';
        }
    }

    function validatePasswordConfirmation() {
        if (confirmPasswordInput.value !== passwordInput.value) {
            passwordConfirmationError.textContent = 'Las contraseñas no coinciden.';
            passwordConfirmationError.style.display = 'block';
        } else {
            passwordConfirmationError.style.display = 'none';
        }
    }

    form.addEventListener('submit', function (event) {
        validateName();
        validateEmail();
        validatePassword();
        validatePasswordConfirmation();

        if (
            nameError.style.display === 'block' ||
            emailError.style.display === 'block' ||
            passwordError.style.display === 'block' ||
            passwordConfirmationError.style.display === 'block'
        ) {
            event.preventDefault();
        }
    });
});
