<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Formulario de calificación</title>
    <script src="https://cdn.tailwindcss.com"></script>
    <link rel="preconnect" href="https://fonts.gstatic.com">
    <link href="https://fonts.googleapis.com/css2?family=Roboto+Mono:wght@400;500;700&display=swap" rel="stylesheet">
</head>
<body class="bg-gray-100 flex justify-center items-center min-h-screen p-4">

    <form id="ratingForm" action="{{ route('ratings.submit', ['token' => $token]) }}" method="POST" class="w-full sm:w-3/4 lg:w-2/3 max-w-xl p-8 bg-white rounded-lg shadow-lg">
        @csrf
        <input type="hidden" name="token" value="{{ $token }}">
        <div class="mb-6 flex justify-center">
            <img src="{{ asset('img/lr.png') }}" class="w-64 h-32 object-contain" alt="Logo Teknologix">
        </div>
        <div class="mb-2">
            <label for="rating" class="block text-sn font-semibold text-gray-700">Calificación</label>
            <select class="mt-2 block w-full p-3 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-orange-500" id="rating" name="rating" required>
                <option value="">Seleccione una calificación</option>
                <option value="1">1 - Muy malo</option>
                <option value="2">2 - Malo</option>
                <option value="3">3 - Regular</option>
                <option value="4">4 - Bueno</option>
                <option value="5">5 - Excelente</option>
            </select>
            <span id="rating-error" class="text-red-500 text-xs"></span>
        </div>
        <div class="mb-2">
            <label for="comments" class="block text-sn font-semibold text-gray-700" aria-placeholder="Opcional">Comentarios</label>
            <textarea class="mt-2 block w-full p-3 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-orange-500" id="comments" name="comments" rows="4"></textarea>
            <span id="comments-error" class="text-red-500 text-xs"></span>
        </div>
        <div class="mb-2">
            <label for="name" class="block text-sn font-semibold text-gray-700">Nombre</label>
            <input type="text" class="mt-2 block w-full p-3 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-orange-500" value="{{ $client->name }}" readonly id="name" name="name" required>
            <span id="name-error" class="text-red-500 text-xs"></span>
        </div>
        <div class="mb-2">
            <label for="email" class="block text-sn font-semibold text-gray-700">Correo electrónico</label>
            <input type="email" class="mt-2 block w-full p-3 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-orange-500" value="{{ $client->email }}" readonly id="email" name="email" required>
            <span id="email-error" class="text-red-500 text-xs"></span>
        </div>
        <div class="mb-2">
            <label for="company" class="block text-sn font-semibold text-gray-700">Empresa</label>
            <input type="text" class="mt-2 block w-full p-3 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-orange-500" value="{{ $client->company->name }}" readonly id="company" name="company" required>
            <span id="company-error" class="text-red-500 text-xs"></span>
        </div>
        <button type="submit" class="w-full py-3 px-6 bg-orange-500 text-white font-semibold rounded-md shadow-lg hover:bg-orange-600 focus:outline-none focus:ring-2 focus:ring-orange-500">
            Enviar calificación
        </button>
    </form>
    <script>
        document.addEventListener('DOMContentLoaded', function () {
            const form = document.getElementById('ratingForm');
            const ratingInput = document.getElementById('rating');
            const nameInput = document.getElementById('name');
            const emailInput = document.getElementById('email');
            const companyInput = document.getElementById('company');
            const commentsInput = document.getElementById('comments');
            const ratingError = document.getElementById('rating-error');
            const nameError = document.getElementById('name-error');
            const emailError = document.getElementById('email-error');
            const companyError = document.getElementById('company-error');
            
            ratingInput.addEventListener('change', validateRating);
            function validateRating() {
                if (ratingInput.value === '') {
                    ratingError.textContent = 'Seleccione una calificación.';
                    ratingError.style.display = 'block';
                } else {
                    ratingError.style.display = 'none';
                }
            }

            nameInput.addEventListener('input', validateName);
            function validateName() {
                if (nameInput.value.trim() === '') {
                    nameError.textContent = 'El nombre es obligatorio.';
                    nameError.style.display = 'block';
                } else {
                    nameError.style.display = 'none';
                }
            }

            emailInput.addEventListener('input', validateEmail);
            function validateEmail() {
                const regex = /^[a-zA-Z0-9._%+-]+@[a-zA-Z0-9.-]+\.[a-zA-Z]{2,}$/;
                if (!regex.test(emailInput.value)) {
                    emailError.textContent = 'Ingrese un correo electrónico válido.';
                    emailError.style.display = 'block';
                } else {
                    emailError.style.display = 'none';
                }
            }

            companyInput.addEventListener('input', validateCompany);
            function validateCompany() {
                if (companyInput.value.trim() === '') {
                    companyError.textContent = 'La empresa es obligatoria.';
                    companyError.style.display = 'block';
                } else {
                    companyError.style.display = 'none';
                }
            }

            form.addEventListener('submit', function (event) {
                let valid = true;
                validateRating();
                validateName();
                validateEmail();
                validateCompany();

                if (ratingError.style.display === 'block' || nameError.style.display === 'block' || emailError.style.display === 'block' || companyError.style.display === 'block') {
                    valid = false;
                }
                if (!valid) {
                    event.preventDefault();
                }
            });
        });
    </script>
</body>
</html>