<x-app-layout>
    <div class="fixed inset-0 flex justify-center items-center bg-gray-800 bg-opacity-50">
        <div class="bg-white dark:bg-slate-800 p-6 rounded-lg w-full md:w-2/3 lg:w-1/2">
            <div class="flex justify-between items-center mb-4">
                <button onclick="closeForm()" class="text-xl text-gray-600 dark:text-gray-300">
                    <i class="fas fa-times"></i>
                </button>
            </div>
            <div class="pb-4">
                <h2 class="text-2xl text-center font-semibold text-gray-800 dark:text-gray-300">
                    @isset($supportCase)
                        Editar Caso
                    @else
                        Nuevo Caso
                    @endisset
                </h2>
            </div>
            <form id="caseForm"
                action="{{ isset($supportCase) ? route('supports.update', $supportCase->id) : route('supports.store') }}"
                method="POST">
                @csrf

                @isset($supportCase)
                    @method('PUT')
                @endisset

                <div class="grid grid-cols-1 sm:grid-cols-2 lg:grid-cols-3 gap-4">

                    <div class="space-y-4">
                        <label for="request_date"
                            class="block text-sm font-medium text-gray-700 dark:text-gray-300">Fecha de
                            solicitud</label>
                        <input type="date" name="request_date" id="request_date"
                            value="{{ old('request_date', $supportCase->request_date ?? '') }}" required
                            class="mt-1 p-2 w-full border border-gray-300 rounded-md shadow-sm
                            text-gray-600 focus:border-slate-400 focus:ring-slate-400
                            dark:text-gray-700">
                        <span id="requestDateError" class="hidden text-xs text-red-600 dark:text-red-300 italic"></span>
                        @if ($errors->has('request_date'))
                            <span
                                class="hidden text-xs text-red-600 dark:text-red-300 italic">{{ $errors->first('request_date') }}</span>
                        @endif

                        <label for="company_id"
                            class="block text-sm font-medium text-gray-700 dark:text-gray-300">Empresa</label>
                        <select name="company_id" id="company_id"
                            class="mt-1 p-2 w-full border border-gray-300 rounded-md shadow-sm
                            text-gray-600 focus:border-slate-400 focus:ring-slate-400
                            dark:text-gray-700"
                            required>
                            <option value="">Seleccionar empresa</option>
                            @foreach ($companies as $company)
                                <option value="{{ $company->id }}"
                                    {{ old('company_id', $supportCase->company_id ?? '') == $company->id ? 'selected' : '' }}>
                                    {{ $company->name }}
                                </option>
                            @endforeach
                        </select>

                        <label for="solution"
                            class="block text-sm font-medium text-gray-700 dark:text-gray-300">Solución</label>
                        <textarea name="solution" id="solution" rows="1"
                            class="mt-1 p-2 w-full border border-gray-300 rounded-md shadow-sm
                            text-gray-600 focus:border-slate-400 focus:ring-slate-400
                            dark:text-gray-700">{{ old('solution', $supportCase->solution ?? '') }}</textarea>
                        <span id="solutionError" class="hidden text-xs text-red-600 dark:text-red-300 italic"></span>
                        @if ($errors->has('solution'))
                            <span
                                class="hidden text-xs text-red-600 dark:text-red-300 italic">{{ $errors->first('solution') }}</span>
                        @endif

                    </div>

                    <div class="space-y-4">
                        <label for="type"
                            class="block text-sm font-medium text-gray-700 dark:text-gray-300">Tipo</label>
                        <input type="text" name="type" id="type"
                            value="{{ old('type', $supportCase->type ?? '') }}" required list="type-options"
                            class="mt-1 p-2 w-full border border-gray-300 rounded-md shadow-sm
                            text-gray-600 focus:border-slate-400 focus:ring-slate-400
                            dark:text-gray-700">
                        <span id="typeError" class="hidden text-xs text-red-600 dark:text-red-300 italic"></span>
                        @if ($errors->has('type'))
                            <span
                                class="hidden text-xs text-red-600 dark:text-red-300 italic">{{ $errors->first('type') }}</span>
                        @endif

                        <datalist id="type-options">
                            <option value="Implemetación"></option>
                            <option value="Capacitación"></option>
                            <option value="Actualización"></option>
                            <option value="Garantía"></option>
                            <option value="Consultoría"></option>
                            <option value="Servicio"></option>
                            <option value="Soporte"></option>
                        </datalist>

                        <label for="client_id"
                            class="block text-sm font-medium text-gray-700 dark:text-gray-300">Cliente</label>
                        <select name="client_id" id="client_id" required
                            class="mt-1 p-2 w-full border border-gray-300 rounded-md shadow-sm
                            text-gray-600 focus:border-slate-400 focus:ring-slate-400
                            dark:text-gray-700">
                            <option value="" disabled selected>Seleccione un cliente</option>
                            @foreach ($clients as $client)
                                <option value="{{ $client->id }}"
                                    {{ old('client_id', $supportCase->client_id ?? '') == $client->id ? 'selected' : '' }}>
                                    {{ $client->name }}
                                </option>
                            @endforeach
                        </select>

                        <label for="resolution_date"
                            class="block text-sm font-medium text-gray-700 dark:text-gray-300">Fecha
                            de
                            resolución</label>
                        <input type="date" name="resolution_date" id="resolution_date"
                            value="{{ old('resolution_date', $supportCase->resolution_date ?? '') }}"
                            class="mt-1 p-2 w-full border border-gray-300 rounded-md shadow-sm
                            text-gray-600 focus:border-slate-400 focus:ring-slate-400
                            dark:text-gray-700">
                        <span id="resolutionDateError"
                            class="hidden text-xs text-red-600 dark:text-red-300 italic"></span>
                        @if ($errors->has('resolution_date'))
                            <span
                                class="hidden text-xs text-red-600 dark:text-red-300 italic">{{ $errors->first('resolution_date') }}</span>
                        @endif
                    </div>

                    <div class="space-y-4">
                        <label for="consultant_id"
                            class="block text-sm font-medium text-gray-700 dark:text-gray-300">Consultor</label>
                        <select name="consultant_id" id="consultant_id"
                            class="mt-1 p-2 w-full border border-gray-300 rounded-md shadow-sm
                            text-gray-600 focus:border-slate-400 focus:ring-slate-400
                            dark:text-gray-700"
                            required>
                            <option value="{{ auth()->user()->id }}" selected>
                                {{ auth()->user()->name }} (Tú)
                            </option>
                            @foreach ($consultants as $consultant)
                                @if ($consultant->id !== auth()->user()->id)
                                    <option value="{{ $consultant->id }}"
                                        {{ old('consultant_id', $supportCase->consultant_id ?? '') == $consultant->id ? 'selected' : '' }}>
                                        {{ $consultant->name }}
                                    </option>
                                @endif
                            @endforeach
                        </select>

                        <label for="issue_description"
                            class="block text-sm font-medium text-gray-700 dark:text-gray-300">Caso reportado</label>
                        <textarea name="issue_description" id="issue_description" rows="1"
                            class="mt-1 p-2 w-full border border-gray-300 rounded-md shadow-sm
                            text-gray-600 focus:border-slate-400 focus:ring-slate-400
                            dark:text-gray-700">{{ old('issue_description', $supportCase->issue_description ?? '') }}</textarea>
                        <span id="issueDescriptionError"
                            class="hidden text-xs text-red-600 dark:text-red-300 italic"></span>
                        @if ($errors->has('issue_description'))
                            <span
                                class="hidden text-xs text-red-600 dark:text-red-300 italic">{{ $errors->first('issue_description') }}</span>
                        @endif

                        <label for="start_time" class="block text-sm font-medium text-gray-700 dark:text-gray-300">Hora
                            inicio</label>
                        <input type="time" name="start_time" id="start_time"
                            value="{{ old('start_time', $supportCase->start_time ?? '') }}"
                            class="mt-1 p-2 w-full border border-gray-300 rounded-md shadow-sm
                            text-gray-600 focus:border-slate-400 focus:ring-slate-400
                            dark:text-gray-700">
                        <span id="startTimeError" class="hidden text-xs text-red-600 dark:text-red-300 italic"></span>
                        @if ($errors->has('start_time'))
                            <span
                                class="hidden text-xs text-red-600 dark:text-red-300 italic">{{ $errors->first('start_time') }}</span>
                        @endif

                        <label for="end_time" class="block text-sm font-medium text-gray-700 dark:text-gray-300">Hora
                            fin</label>
                        <input type="time" name="end_time" id="end_time"
                            value="{{ old('end_time', $supportCase->end_time ?? '') }}"
                            class="mt-1 p-2 w-full border border-gray-300 rounded-md shadow-sm
                            text-gray-600 focus:border-slate-400 focus:ring-slate-400
                            dark:text-gray-700">
                        <span id="endTimeError" class="hidden text-xs text-red-600 dark:text-red-300 italic"></span>
                        @if ($errors->has('end_time'))
                            <span
                                class="hidden text-xs text-red-600 dark:text-red-300 italic">{{ $errors->first('end_time') }}</span>
                        @endif
                    </div>
                </div>

                <div class="space-y-4 pt-2">
                    <label for="opportunity"
                        class="block text-sm font-medium text-gray-700 dark:text-gray-300">Oportunidad</label>
                    <textarea name="opportunity" id="opportunity" rows="2"
                        class="mt-1 p-2 w-full border border-gray-300 rounded-md shadow-sm
                            text-gray-600 focus:border-slate-400 focus:ring-slate-400
                            dark:text-gray-700">{{ old('opportunity', $supportCase->opportunity ?? '') }}</textarea>
                    <span id="opportunityError" class="hidden text-xs text-red-600 dark:text-red-300 italic"></span>
                    @if ($errors->has('opportunity'))
                        <span
                            class="hidden text-xs text-red-600 dark:text-red-300 italic">{{ $errors->first('opportunity') }}</span>
                    @endif
                </div>

                <div class="flex justify-end mt-6">
                    <button type="submit"
                        class="bg-naranja text-white py-2 px-6 rounded-md hover:bg-naranja-dark focus:outline-none focus:ring-2 focus:ring-naranja focus:ring-opacity-50">
                        Guardar
                    </button>
                </div>
            </form>
        </div>
    </div>
    <script>
        function closeForm() {
            window.history.back();
        }
    </script>
</x-app-layout>
