<x-app-layout>
    <h2 class="font-bold text-xl text-gray-800 leading-tight lg:px-8 py-2 dark:text-white">
        {{ __('NUEVO USUARIO') }}
    </h2>
    <div class="py-2">
        <div class="max-w-7xl mx-auto sm:px-6 lg:px-8">
            <div class="bg-white overflow-hidden shadow-sm sm:rounded-lg dark:bg-gray-800">
                <div class="p-6 text-gray-900 dark:text-gray-100">
                    <div class="flex justify-end items-center mb-4">
                        <button onclick="window.location='{{ route('users.index') }}'" class="text-xl text-gray-600 dark:text-gray-300">
                            <i class="fas fa-times"></i>
                        </button>
                    </div>
                    @if ($errors->any())
                        <div class="alert alert-dark alert-dismissible fade show" role="alert">
                            <strong>¡Revise los campos!</strong>
                            @foreach ($errors->all() as $error)
                                <span class="badge badge-danger">{{$error}}</span>
                            @endforeach
                            <button type="button" class="close" data-dismiss="alert" aria-label="Close">
                                <span aria-hidden="true">&times;</span>
                            </button>
                        </div>
                    @endif

                    <form id ="userForm" action="{{ route('users.store') }}" method="POST" enctype="multipart/form-data">
                        @csrf
                        <div class="grid grid-cols-1 sm:grid-cols-2 gap-4">
                            <div>
                                <label for="name" class="block font-medium text-gray-700 dark:text-gray-300">Nombre</label>
                                <input id="name" type="text" name="name" class="mt-1 p-2 w-full border border-gray-300 rounded-md shadow-sm text-gray-600 dark:text-gray-700 focus:border-slate-400 focus:ring-slate-400" value="{{ old('name') }}" required>
                                <span id="name-error" class="text-red-500 text-xs"></span>
                            </div>

                            <div>
                                <label for="email" class="block font-medium text-gray-700 dark:text-gray-300">E-mail</label>
                                <input id="email" type="email" name="email" class="mt-1 p-2 w-full border border-gray-300 rounded-md shadow-sm text-gray-600 dark:text-gray-700 focus:border-slate-400 focus:ring-slate-400" value="{{ old('email') }}" required>
                                <span id="email-error" class="text-red-500 text-xs"></span>
                            </div>

                            <div>
                                <label for="password" class="block font-medium text-gray-700 dark:text-gray-300">Contraseña</label>
                                <input id="password" type="password" name="password" class="mt-1 p-2 w-full border border-gray-300 rounded-md shadow-sm text-gray-600 dark:text-gray-700 focus:border-slate-400 focus:ring-slate-400" required>
                                <span id="password-error" class="text-red-500 text-xs"></span>
                            </div>

                            <div>
                                <label for="confirm-password" class="block font-medium text-gray-700 dark:text-gray-300">Confirmar contraseña</label>
                                <input id="confirm-password" type="password" name="confirm-password" class="mt-1 p-2 w-full border border-gray-300 rounded-md shadow-sm text-gray-600 dark:text-gray-700 focus:border-slate-400 focus:ring-slate-400" required>
                                <span id="password-confirmation-error" class="text-red-500 text-xs"></span>
                            </div>

                            <div>
                                <label for="roles" class="block font-medium text-gray-700 dark:text-gray-300">Roles</label>
                                <select id="roles" name="roles[]" class="form-control mt-1 block w-full p-2 border border-gray-300 rounded-md shadow-sm dark:text-gray-700 focus:border-slate-400 focus:ring-slate-400 sm:text-sm">
                                    @foreach($roles as $role)
                                        <option value="{{ $role }}" @if(in_array($role, old('roles', []))) selected @endif>{{ $role }}</option>
                                    @endforeach
                                </select>
                            </div>

                            <div class="col-span-1">
                                <label for="photo" class="block text-gray-700 font-medium dark:text-gray-300">Imagen</label>
                                <input id="photo" type="file" id="photo" name="photo" class="hidden" accept="image/*" onchange="updateFileName()">

                                <label for="photo"
                                    class="block cursor-pointer p-2 bg-white border border-gray-300 rounded-md text-sm font-medium text-gray-700 hover:bg-gray-50 focus:outline-none focus:ring-2 focus:ring-green-500 focus:border-green-500 w-full sm:text-sm">
                                    <span class="truncate py-4">Seleccionar archivo</span>
                                </label>

                                <x-input-error :messages="$errors->get('photo')" class="mt-2" />
                                <span id="file-name-users"></span>
                            </div>

                            <div class="col-span-2 flex justify-center">
                                <button type="submit" class="px-4 py-2 w-64 bg-orange-500 text-white font-bold rounded-md hover:bg-orange-700 focus:outline-none">
                                    Guardar
                                </button>
                            </div>
                        </div>
                    </form>
                </div>
            </div>
        </div>
    </div>
</x-app-layout>
