<x-app-layout>
    <h2 class="font-bold text-xl text-gray-800 leading-tight lg:px-8 py-2 dark:text-white">
        {{ __('EDITAR USUARIO') }}
    </h2>

    <div class="py-2">
        <div class="max-w-7xl mx-auto sm:px-6 lg:px-8">
            <div class="bg-white overflow-hidden shadow-sm sm:rounded-lg dark:bg-gray-800">
                <div class="p-6 text-gray-900 dark:text-gray-100">
                    <div class="flex justify-end items-center mb-4">
                        <button onclick="window.location='{{ route('users.index') }}'" class="text-xl text-gray-600 dark:text-gray-300">
                            <i class="fas fa-times"></i>
                        </button>
                    </div>
                    @if ($errors->any())
                    <div class="bg-red-100 border-l-4 border-red-500 text-red-700 p-4 mb-4">
                        <strong>¡Revise los campos!</strong>
                        <ul>
                            @foreach ($errors->all() as $error)
                                <li>{{ $error }}</li>
                            @endforeach
                        </ul>
                    </div>
                    @endif

                    <form id="userForm" action="{{ route('users.update', $user->id) }}" method="POST" enctype="multipart/form-data">
                        @csrf
                        @method('PUT')
                        <div class="grid grid-cols-1 sm:grid-cols-2 gap-4">

                            <div class="mb-4 flex items-center justify-center">
                                <img src="{{ asset($user->photo) }}" alt="Foto de perfil actual"
                                    class="mt-2 w-30 h-20 object-cover">
                            </div>

                            <div class="mb-4">
                                <x-input-label for="photo" :value="__('Foto de perfil')" />
                                <input type="file" id="photo" name="photo" class="hidden" accept="image/*"
                                    onchange="updateFileName()">

                                <label for="photo"
                                    class="block cursor-pointer bg-white py-2  px-3 border border-gray-300 rounded-md text-sm font-medium text-gray-700 hover:bg-gray-50 focus:outline-none focus:ring-2 focus:ring-green-500 focus:border-green-500 w-full sm:text-sm">
                                    <span class="truncate py-4">Seleccionar archivo</span>
                                </label>

                                <x-input-error :messages="$errors->get('photo')" class="mt-2" />
                                <span id="file-name-users"></span>
                            </div>

                            <div>
                                <label for="name" class="block text-gray-700 font-medium dark:text-gray-300">Nombre</label>
                                <input id="name" type="text" name="name" class="w-full border-gray-300 p-2 rounded-md shadow-sm focus:outline-none focus:ring-2 focus:ring-indigo-500 mt-1 dark:text-gray-700" value="{{ old('name', $user->name) }}" required>
                                <span id="name-error" class="text-red-500 text-xs"></span>
                            </div>

                            <div>
                                <label for="email" class="block text-gray-700 font-medium dark:text-gray-300">E-mail</label>
                                <input id="email" type="email" name="email" class="w-full border-gray-300 p-2 rounded-md shadow-sm focus:outline-none focus:ring-2 focus:ring-indigo-500 dark:text-gray-700" value="{{ old('email', $user->email) }}">
                                <span id="email-error" class="text-red-500 text-xs"></span>
                            </div>

                            <div>
                                <label for="password" class="block text-gray-700 font-medium dark:text-gray-300">Nueva contraseña</label>
                                <input id="password" type="password" name="password" class="w-full border-gray-300 p-2 rounded-md shadow-sm focus:outline-none focus:ring-2 focus:ring-indigo-500 dark:text-gray-700">
                                <span id="password-error" class="text-red-500 text-xs"></span>
                            </div>

                            <div>
                                <label for="confirm-password" class="block text-gray-700 font-medium dark:text-gray-300">Confirmar contraseña</label>
                                <input id="confirm-password" type="password" name="confirm-password" class="w-full border-gray-300 p-2 rounded-md shadow-sm focus:outline-none focus:ring-2 focus:ring-indigo-500 dark:text-gray-700">
                                <span id="password-confirmation-error" class="text-red-500 text-xs"></span>
                            </div>

                            <div>
                                <label for="roles" class="block text-gray-700 font-medium dark:text-gray-300">Rol</label>
                                <select id="roles" name="roles[]" class="w-full border-gray-300 p-2 rounded-md shadow-sm focus:outline-none focus:ring-2 focus:ring-indigo-500 dark:text-gray-700">
                                    @foreach($roles as $roleName)
                                        <option value="{{ $roleName }}" 
                                            @if(in_array($roleName, $userRole)) selected @endif>
                                            {{ $roleName }}
                                        </option>
                                    @endforeach
                                </select>
                            </div>

                            <div class="text-center">
                                <button type="submit" class="px-4 py-2 bg-naranja text-white font-bold rounded-md hover:bg-orange-700 focus:outline-none">
                                    Actualizar
                                </button>
                            </div>
                        </div>
                    </form>

                </div>
            </div>
        </div>
    </div>
</x-app-layout>
