<?php

use App\Http\Controllers\ProfileController;
use Illuminate\Support\Facades\Route;
use App\Http\Controllers\GoalController;
use App\Http\Controllers\DashboardController;
use App\Http\Controllers\TaskController;
use App\Http\Controllers\CompanyController;
use App\Http\Controllers\ClientController;
use App\Http\Controllers\SupportCaseController;
use App\Models\SupportCase;
use  App\Http\Controllers\BackupController;

// Controllers 

use App\Http\Controllers\RoleController;
use App\Http\Controllers\UserController;
use App\Http\Controllers\ReportController;
use App\Http\Controllers\GraphController;
use App\Http\Controllers\RatingController;

Route::get('/', function () {
    return view('welcome');
});

Route::get('/dashboard', function () {
    return view('dashboard');
})->middleware(['auth', 'verified'])->name('dashboard');

Route::middleware('auth')->group(function () {
    Route::get('/profile', [ProfileController::class, 'edit'])->name('profile.edit');
    Route::patch('/profile', [ProfileController::class, 'update'])->name('profile.update');
    Route::delete('/profile', [ProfileController::class, 'destroy'])->name('profile.destroy');
});


Route::get('/goals/progress', [GoalController::class, 'progress'])->name('goals.progress');
Route::get('/goals/previous', [GoalController::class, 'show'])->name('goals.previous');
Route::middleware(['auth'])->group(function () {
    Route::resource('goals', GoalController::class);
    Route::post('/goals/update-progress/{goal}', [GoalController::class, 'updateProgress']);
});

Route::get('/dashboard', [DashboardController::class, 'index'])->name('dashboard');


Route::middleware(['auth'])->group(function () {
    Route::resource('tasks', TaskController::class);
});

Route::resource('companies', CompanyController::class);
Route::resource('clients', ClientController::class);
Route::resource('supports', SupportCaseController::class);
Route::get('/indicators', [SupportCaseController::class, 'indicators'])->name('supports.indicators');

require __DIR__ . '/auth.php';

Route::group(['middleware' => ['auth']], function () {
    Route::resource('roles', RoleController::class);
    Route::resource('users', UserController::class);

    Route::get('mascarLeidas', function () {
        auth()->user()->unreadNotifications->markAsRead();
        return redirect()->back();
    })->name('marcarLeidas');

    Route::post('/mostrar-leidas', [TaskController::class, 'marcarNotification'])->name('marcarNotificaciones');
});

Route::get('/reports', [ReportController::class, 'index'])->name('reports.index');
Route::get('/reports-metas', [ReportController::class, 'goalsReport'])->name('reports.metas');
Route::get('/reports/supports', [ReportController::class, 'supportsReport'])->name('reports.supports');



Route::get('/graphs', [GraphController::class, 'index'])->name('graphs');
Route::get('/graph-goals', [GraphController::class, 'graphGoals'])->name('graphs.graph-goals');
Route::get('/graphs-supports', [GraphController::class, 'graphSupports'])->name('graphs.graph-supports');


// Ruta de las notificaciones

Route::get('/task-notifications', [TaskController::class, 'mostrarNotificaciones'])->name('tasks.mostrarNotificaciones');

// Ruta Backup
Route::get('/backup', [BackupController::class, 'Backup'])->name('backup');

// Calificaciones
Route::get('/ratings', [RatingController::class, 'index'])->name('ratings.index');
Route::post('/send-rating-link', [RatingController::class, 'sendRatingLink'])->name('ratings.send');
Route::get('/rating/{token}', [RatingController::class, 'showRatingForm'])->name('ratings.form');
// Route::post('/submit-rating/{token}', [RatingController::class, 'submitRating'])->name('ratings.submit');
Route::post('/submit-rating/{token}', [RatingController::class, 'submitRating'])->name('ratings.submit');

Route::get('/show-ratings', [RatingController::class, 'showRatings'])->name('ratings.show');

Route::view('/thank-you', 'thank-you')->name('thank-you');
