<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\User;
use Carbon\Carbon;
use App\Models\Task;

class DashboardController extends Controller
{
    public function index()
    {
        // Obtener el inicio de la semana actual
        $startOfWeek = Carbon::now()->startOfWeek();
        $currentWeekNumber = $startOfWeek->weekOfYear;
        $weekNumber = Carbon::now()->weekOfYear;

        $users = User::with('goals')->get()->take(5);
        // Metas
        foreach ($users as $user) {
            // Filtrar metas de la semana actual
            $currentWeekGoals = $user->goals->filter(function ($goal) use ($currentWeekNumber) {
                return $goal->week_number == $currentWeekNumber;
            });

            $user->currentWeekGoals = $currentWeekGoals->take(4);

            // 🔹 Calcular progreso
            $totalGoals = $currentWeekGoals->sum('total_goals');
            $completedGoals = $currentWeekGoals->sum('completed_goals');

            $user->progress = ($totalGoals > 0) ? ($completedGoals / $totalGoals) * 100 : 0;
        }

        // Tareas por día 
        $daysOfWeek = ['Lunes' => 0, 'Martes' => 1, 'Miércoles' => 2, 'Jueves' => 3, 'Viernes' => 4];

        $tasksByDay = [];
        foreach ($daysOfWeek as $spanishDay => $index) {
            $date = $startOfWeek->copy()->addDays($index)->toDateString();
            $tasksByDay[$spanishDay] = Task::whereDate('activity_date', $date)->get();
        }

        // Semana
        $currentDate = Carbon::now();
        $monthName = $currentDate->locale('es')->isoFormat('MMMM');
        $diaDelMes = Carbon::now()->day;
        $nombreDia = Carbon::now()->locale('es')->isoFormat('dddd');
        $startOfWeekFormatted = $startOfWeek->format('d/m/Y');
        $endOfWeekFormatted = $startOfWeek->endOfWeek()->format('d/m/Y');

        return view('dashboard', compact('users', 'currentWeekNumber', 'tasksByDay', 'daysOfWeek', 'monthName', 'diaDelMes', 'startOfWeekFormatted', 'endOfWeekFormatted', 'weekNumber', 'nombreDia'));
    }
}
