document.addEventListener('DOMContentLoaded', function () {
    const form = document.getElementById('goalForm');
    const titleInput = document.getElementById('title');
    const descriptionInput = document.getElementById('description');
    const totalGoalsInput = document.getElementById('total_goals');
    const completedGoalsInput = document.getElementById('completed_goals');
    const startDateInput = document.getElementById('start_date');
    const endDateInput = document.getElementById('end_date');

    const titleError = document.getElementById('titleError');
    const descriptionError = document.getElementById('descriptionError');
    const totalGoalsError = document.getElementById('totalGoalsError');
    const completedGoalsError = document.getElementById('completedGoalsError');
    const startDateError = document.getElementById('startDateError');
    const endDateError = document.getElementById('endDateError');

    titleInput.addEventListener('input', validateTitle);
    descriptionInput.addEventListener('input', validateDescription);
    totalGoalsInput.addEventListener('input', validateTotalGoals);
    completedGoalsInput.addEventListener('input', validateCompletedGoals);
    startDateInput.addEventListener('input', validateStartDate);
    endDateInput.addEventListener('input', validateEndDate);


    function validateTitle() {
        const regex = /^[a-zA-Z0-9áéíóúÁÉÍÓÚüÜñÑ\s\.\-\"\'\,]+$/;
        const maxLength = 50;
        const titleValue = titleInput.value;

        // Verificar si el campo está vacío o no pasa la validación del regex
        if (titleValue && !regex.test(titleValue)) {
            titleError.textContent =
                'El título solo puede contener letras, números, espacios, puntos, guiones, acentos, comillas y comas.';
            titleError.style.display = 'block';
        }
        // Verificar si el título excede el límite de 50 caracteres
        else if (titleValue.length > maxLength) {
            titleError.textContent = `El título no puede exceder los ${maxLength} caracteres.`;
            titleError.style.display = 'block';
        } else {
            titleError.style.display = 'none';
        }
    }


    function validateDescription() {
        const regex = /^[a-zA-Z0-9áéíóúÁÉÍÓÚüÜñÑ\s\.\-\"\'\,]+$/;
        const maxLength = 255;
        const descriptionValue = descriptionInput.value;

        if (descriptionValue && !regex.test(descriptionValue)) {
            descriptionError.textContent = 'La descripción solo puede contener letras, números, espacios, puntos, guiones, acentos, comillas y comas.';
            descriptionError.style.display = 'block';
        }
        else if (descriptionValue.length > maxLength) {
            descriptionError.textContent = `La descripción no puede exceder los ${maxLength} caracteres.`;
            descriptionError.style.display = 'block';
        } else {
            descriptionError.style.display = 'none';
        }
    }



    function validateTotalGoals() {
        if (totalGoalsInput.value && totalGoalsInput.value < 1) {
            totalGoalsError.textContent = 'El número total de metas debe ser un número mayor a 0.';
            totalGoalsError.style.display = 'block';
        } else {
            totalGoalsError.style.display = 'none';
        }
    }

    function validateCompletedGoals() {
        if (completedGoalsInput.value && completedGoalsInput.value < 0) {
            completedGoalsError.textContent = 'Las metas completadas no pueden ser un número negativo.';
            completedGoalsError.style.display = 'block';
        } else {
            completedGoalsError.style.display = 'none';
        }
    }

    function validateStartDate() {
        const today = new Date();
        today.setHours(0, 0, 0, 0); // Elimina la hora para evitar problemas de comparación

        const selectedDate = new Date(startDateInput.value + 'T00:00:00'); // Fuerza la fecha sin hora

        if (!startDateInput.value || isNaN(selectedDate)) {
            startDateError.textContent = 'La fecha de inicio no es válida.';
            startDateError.style.display = 'block';
        } else if (selectedDate < today) {
            startDateError.textContent = 'La fecha de inicio debe ser mayor o igual al día actual.';
            startDateError.style.display = 'block';
        } else {
            startDateError.style.display = 'none'; // No mostrar error si la fecha es válida
        }
    }

    function validateEndDate() {
        const today = new Date();
        today.setHours(0, 0, 0, 0); // Elimina la hora para evitar problemas de comparación

        const startDate = new Date(startDateInput.value + 'T00:00:00'); // Fecha de inicio sin hora
        const endDate = new Date(endDateInput.value + 'T00:00:00'); // Fecha de fin sin hora

        if (!endDateInput.value || isNaN(endDate)) {
            endDateError.textContent = 'La fecha de fin no es válida.';
            endDateError.style.display = 'block';
        } else if (endDate < today) {
            endDateError.textContent = 'La fecha de fin debe ser mayor o igual al día actual.';
            endDateError.style.display = 'block';
        } else if (!startDateInput.value || isNaN(startDate)) {
            endDateError.textContent = 'Debe seleccionar una fecha de inicio válida antes de elegir la fecha de fin.';
            endDateError.style.display = 'block';
        } else if (endDate < startDate) {
            endDateError.textContent = 'La fecha de fin debe ser posterior o igual a la fecha de inicio.';
            endDateError.style.display = 'block';
        } else {
            endDateError.style.display = 'none'; // No mostrar error si la fecha es válida
        }
    }


    form.addEventListener('submit', function (event) {
        validateTitle();
        validateDescription();
        validateTotalGoals();
        validateCompletedGoals();
        validateStartDate();
        validateEndDate();

        // Si hay errores, no se envía el formulario
        if (titleError.style.display === 'block' ||
            descriptionError.style.display === 'block' ||
            totalGoalsError.style.display === 'block' ||
            completedGoalsError.style.display === 'block' ||
            startDateError.style.display === 'block' ||
            endDateError.style.display === 'block') {
            event.preventDefault();
        }
    });
});
