<x-app-layout>
    <x-slot name="header">
        <h2 class="font-semibold text-xl text-gray-800 leading-tight">
            {{ __('Gráfica de casos por tipo de soporte') }}
        </h2>
    </x-slot>

    <div class="py-12">
        <div class="max-w-7xl mx-auto sm:px-6 lg:px-8">
            <div class="bg-white overflow-hidden shadow-sm sm:rounded-lg p-6">
                <h2 class="text-lg font-bold mb-4 text-center text-gray-700">Gráfica de casos por tipo de soporte</h2>

                <form id="filterForm" action="{{ route('graphs.graph-supports') }}" method="GET" class="mb-6 flex flex-col md:flex-row items-center gap-4">
                    <div class="flex-1 flex items-center">
                        <label for="month" class="block text-sm font-medium text-gray-700 mr-2">Seleccionar mes:</label>
                        <input type="month" id="month" name="month" class="border p-2 rounded w-full shadow-sm focus:ring focus:ring-blue-300" value="{{ request('month') }}">
                    </div>

                    <button type="submit" class="bg-blue-500 hover:bg-blue-700 text-white font-bold py-2 px-4 rounded shadow md:w-auto w-full">
                        Filtrar
                    </button>
                </form>

                <div class="w-full bg-gray-50 p-4 rounded-lg shadow md:w-1/2">
                    <h3 class="text-center font-semibold text-gray-700 mb-3">Gráfica de {{ $month->format('F') }} por tipo de soporte</h3>
                    <canvas id="casesChart"></canvas>
                </div>
            </div>
        </div>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
    <script>
        document.addEventListener("DOMContentLoaded", function () {
            const ctx = document.getElementById('casesChart').getContext('2d');
            
            const types = @json(array_keys($casesByTypeArray));
            const caseCounts = @json(array_values($casesByTypeArray));

            function generateRandomColor() {
                const letters = '0123456789ABCDEF';
                let color = '#';
                for (let i = 0; i < 6; i++) {
                    color += letters[Math.floor(Math.random() * 16)];
                }
                return color;
            }

            const backgroundColors = caseCounts.map(() => generateRandomColor());
            
            let casesChart = new Chart(ctx, {
                type: 'bar',
                data: {
                    labels: types,
                    datasets: [{
                        label: 'Casos por tipo de soporte',
                        data: caseCounts,
                        backgroundColor: backgroundColors,
                        borderColor: '#388E3C',
                        borderWidth: 1
                    }]
                },
                options: {
                    responsive: true,
                    scales: {
                        y: {
                            beginAtZero: true
                        }
                    }
                }
            });
        });
    </script>
</x-app-layout>